/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxInterceptorExcludeClassInterceptorsVisitor.java 450 2006-05-12 15:30:25Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.analyzer;

import org.ow2.easybeans.deployment.annotations.metadata.interfaces.IInterceptorExcludeDefaultInterceptors;

/**
 * This class manages the handling of &#64;{@link javax.interceptor.ExcludeDefaultInterceptors}
 * annotation.
 * @param <T> An implementation of IInterceptorExcludeDefaultInterceptors interface.
 * @author Florent Benoit
 */
public class JavaxInterceptorExcludeDefaultInterceptorsVisitor<T extends IInterceptorExcludeDefaultInterceptors> extends
        AbsAnnotationVisitor<T> implements AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/interceptor/ExcludeDefaultInterceptors;";

    /**
     * Constructor.
     * @param annotationMetadata linked to a class or method or field metadata
     */
    public JavaxInterceptorExcludeDefaultInterceptorsVisitor(final T annotationMetadata) {
        super(annotationMetadata);
    }

    /**
     * Visits the end of the annotation.<br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        // set flag on method
        getAnnotationMetadata().setExcludeDefaultInterceptors(true);

    }

    /**
     * @return type of the annotation (its description)
     */
    public String getType() {
        return TYPE;
    }

}
